Module: Static::ReadOauthList
- Defined in:
- lib/static.rb
Constant Summary collapse
- Name =
"ReadOauthList"- Query =
<<-EOS query ReadOauthList($clientId: String, $dontGetURL: Boolean, $useGuard: Boolean){ ReadOauthList(clientId: $clientId, dontGetURL: $dontGetURL, useGuard: $useGuard){ _id name alias image description enabled url client user oAuthUrl wxappLogo fields{ label type placeholder value checked } oauth{ _id name alias image description enabled url client user oAuthUrl wxappLogo } } } EOS